% SAUVEGRADS : Crée un fichier (.dat)  et un fichier de définition  (.ctl)
% dans le répertoire courant pour utilisation avec le logiciel GRADS
%
% SAUVEGRADS(NOMFICH,MATRICE,POSIT)
%
% Les arguments en entrée sont :
% NOMFICH : Nom du fichier  à partir duquel sont créé les fichiers:
%           'nomfich'.dat qui est le fichiers des données
%           'nomfich'.ctl qui est le fichier de définition pour les données,
%           c'est ce fichier qui doit être appelé sous GRADS (open nomfich.ctl)
% MATRICE : Nom de la matrice à sauver
% POSIT   : Coordonnées  indiquant la position de matrice par rapport à la
%           carte du monde. Ces coordonnées [LON INCLON LAT INCLAT] sont
%           la latitude et longitude du point initial de la matrice et leur
%           pas d'incrémentation respectif.
%           Toutes ces coordonnées sont en degré.
%
% Attention: La matrice sera inversé verticalement entre MATLAB ET GRADS
%            du fait que les coordonnées latitude progresse vers le haut
%            et que sous MATLAB en augmentant l'indice on progresse vers le bas.
%
%    Voir aussi XGRADS

function h = sauvegrads(nomfich,matrice,posit)
% JMG le 10/03/94

if nargin < 3
	error('Il n''y a pas assez d''arguments.');
	return
elseif nargin > 3
	error('Il y a trop d''arguments.')
	return
end

% orientation de la matrice
% sans le flipud la matrice sera inverser verticalement entre grads et matlab
% ce qui est normal puisque l'on utilise les coordonnées Longitude,latitude
% sous grads et en incrementant la latitude on progresse vers le haut
% alors qu'avec matlab on progresse vers le bas en incrementant l'indice
%matrice=flipud(matrice);
mat1=fliplr(matrice);
mat2=rot90(mat1);
nomfichdat=[nomfich,'.dat'];
nomfichctl=[nomfich,'.ctl'];

fprintf(1,'Création du fichier de données %s \n',nomfichdat);
% ouverture du fichier .dat
fid=fopen(nomfichdat,'w');
% ecriture de la matrice
fwrite(fid,mat2,'float32');
fclose(fid);


% init des variables
[sxp syp]=size(posit);
if (syp~=4)
  error('La syntaxe est incorrect , il faut 4 arguments pour POSIT');
  return
end
lon=posit(1);
inclon=posit(2);
lat=posit(3);
inclat=posit(4);
% ici on peut rajouter les test pour voir si les coordonnées en degrées sont bonnes
if (abs(lon)>180)
  error('La longitude doit être comprise entre -180 et 180');
  return
elseif (abs(lat>90))
  error('La latitude doit être comprise entre -90 et 90')
  return
end


% Init date du jour pour enregistrement
date1=date;
date2=[date1(1:2),upper(date1(4:6)),'19',date1(8:9)];
% test sur les arguments
[dimy dimx]=size(matrice);

fprintf(1,'Création du fichier de définition %s \n',nomfichctl);
% ouverture du fichier .ctl
fid=fopen(nomfichctl,'w');

% ecriture ligne par ligne du fichier
texte=['DSET ^',nomfichdat,' ',10];
fwrite(fid,texte,'char');
texte=['UNDEF -2E5633 ',10];
fwrite(fid,texte,'char');
texte=['TITLE Fichier généré par la fonction sauvegrads de MATLAB ',10];
fwrite(fid,texte,'char');
texte=['XDEF ',num2str(dimx),' LINEAR ',num2str(lon),'  ',num2str(inclon),' ',10];
fwrite(fid,texte,'char');
texte=['YDEF ',num2str(dimy),' LINEAR ',num2str(lat),'  ',num2str(inclat),' ',10];
fwrite(fid,texte,'char');
texte=['ZDEF ',num2str(dimx*dimy),' LINEAR  1  1 ',10];
fwrite(fid,texte,'char');
texte=['TDEF 1 LINEAR ',num2str(date2),' 1DY ',10];
fwrite(fid,texte,'char');
texte=['VARS 1 ',10];
fwrite(fid,texte,'char');
texte=[nomfich,'      0   99  ',num2str(dimx*dimy),'   Matrice d''isovaleurs de MATLAB ',10];
fwrite(fid,texte,'char');
texte=['ENDVARS ',10];
fwrite(fid,texte,'char');

% fermeture du fichier
fclose(fid);