#! /bin/sh
#
#+
#
# NAME
# ====
#
# dlogd.sh - prompt for destruction of the most recent release of ${IRCAAM_LOG}/action.log.YYYY-MM-DDTHH:MM:SSZ
#
#
# SYNOPSIS
# ========
#
# ::
#
#  $ dlogd.sh action
#
#
# DESCRIPTION
# ===========
#
# ``dlogd.sh`` prompt for destruction of the most recent release of ${IRCAAM_LOG}/action.log.YYYY-MM-DDTHH:MM:SSZ.
#
# 
# SEE ALSO
# ========
#
# ircaam_profile.sh_
# 
# .. _ircaam_profile.sh : ircaam_profile.sh.html
# 
# elogd.sh_
#  
# .. _elogd.sh : elogd.sh.html
# 
# plogd.sh_
#  
# .. _plogd.sh : plogd.sh.html
#
# tlogd.sh_
#  
# .. _tlogd.sh : tlogd.sh.html
#
# FILES
# =====
#
# original location
# ~~~~~~~~~~~~~~~~~
#
# /usr/home/fplod/incas/ircaam/ircaam_ws/src/dlogd.sh sur cerbere.locean-ipsl.upmc.fr
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# - fplod 2006-02-20T16:44:33Z aedon.lodyc.jussieu.fr (Darwin)
#
#   * posix
#
#-
#
set -u
system=$(uname)
case "${system}" in
AIX|IRIX64)
  echo " www : no specific posix checking"
;;
*)
  set -o posix
;;
esac
command=$(basename ${0})
#
if [ "${1}" = "" ]
then
   echo "${command} : eee : 1st parameter missing" >&2
   exit 1
fi
#
# check for ${IRCAAM_LOG} definition
if [ "${IRCAAM_LOG}" = "" ]
then 
 echo " eee : \${IRCAAM_LOG} not defined"
 exit 1
fi
#
# check for ${IRCAAM_LOG} existence
if [ ! -d ${IRCAAM_LOG} ]
then
 echo " eee : ${IRCAAM_LOG} not found"
 exit 1
fi
#
# check for permission access on IRCAAM_LOG
if [ ! -x ${IRCAAM_LOG} ]
then
 echo " eee : ${IRCAAM_LOG} not reachable"
 exit 1
fi
# check for write permission on IRCAAM_LOG
if [ ! -w ${IRCAAM_LOG} ]
then
 echo " eee : ${IRCAAM_LOG} not writable"
 exit 1
fi
#
log=$(find ${IRCAAM_LOG} -name "${1}.log.????-??-??T??:??:??Z" | sort | \
tail -n 1)
tmp=${?}
if [ ${tmp} -eq 0 ]
then
 if [ "${log}" = "" ]
 then
  echo "${command} : eee : no release of ${IRCAAM_LOG}/${1}.log" >&2
  exit 1
 else
  # destruction du fichier ${log}
  /bin/rm -i ${log}
  exit 0
 fi
else
 exit 1
fi
